@@ -11,6 +11,11 @@ from applitools.common.match_window_data import MatchWindowData, Options
 from applitools.common.ultrafastgrid import VisualGridSelector
 from applitools.common.utils import datetime_utils, image_utils
 from applitools.core.capture import AppOutputProvider, AppOutputWithScreenshot
+from applitools.core.fluent.region import (
+    AccessibilityRegionByRectangle,
+    FloatingRegionByRectangle,
+    RegionByRectangle,
+)
 
 from .fluent import CheckSettings, GetAccessibilityRegion, GetFloatingRegion, GetRegion
 
@@ -131,6 +136,49 @@ def collect_regions_from_selectors(image_match_settings, regions, region_selecto
     return image_match_settings
 
 
+def _coded_regions(region_providers):
+    regions = []
+    coded_region_types = (
+        RegionByRectangle,
+        AccessibilityRegionByRectangle,
+        FloatingRegionByRectangle,
+    )
+    for rp in region_providers:
+        if isinstance(rp, coded_region_types):
+            regions.extend(rp.get_regions(None, None))
+    return regions
+
+
+def collect_append_coded_regions(check_settings, image_match_settings):
+    # type:(CheckSettings,ImageMatchSettings,EyesScreenshot,EyesBase)->ImageMatchSettings
+    for ims_region, settings_region in (
+        (image_match_settings.ignore_regions, check_settings.values.ignore_regions),
+        (image_match_settings.layout_regions, check_settings.values.layout_regions),
+        (image_match_settings.strict_regions, check_settings.values.strict_regions),
+        (image_match_settings.content_regions, check_settings.values.content_regions),
+        (
+            image_match_settings.floating_match_settings,
+            check_settings.values.floating_regions,
+        ),
+        (
+            image_match_settings.accessibility,
+            check_settings.values.accessibility_regions,
+        ),
+    ):
+        ims_region.extend(_coded_regions(settings_region))
+
+    logger.debug(
+        """
+    finish collect_append_coded_regions()
+
+        image_match_settings: {}
+    """.format(
+            image_match_settings
+        )
+    )
+    return image_match_settings
+
+
 def collect_regions_from_screenshot(
     check_settings, image_match_settings, screenshot, eyes
 ):
@@ -289,12 +337,16 @@ class MatchWindowTask(object):
             image_match_settings = collect_regions_from_screenshot(
                 check_settings, image_match_settings, screenshot, eyes
             )
-        elif regions and region_selectors:
+        else:
             # visual grid
-            image_match_settings = collect_regions_from_selectors(
-                image_match_settings, regions, region_selectors
-            )
-
+            if regions and region_selectors:
+                image_match_settings = collect_regions_from_selectors(
+                    image_match_settings, regions, region_selectors
+                )
+            if check_settings:
+                image_match_settings = collect_append_coded_regions(
+                    check_settings, image_match_settings
+                )
         user_inputs = user_inputs or []
         agent_setup = self._eyes.agent_setup
         return self._perform_match(
